@@ -6,6 +6,9 @@ from .BamFile import BamFile
 from .TbxFile import TbxFile
 from .GtfFile import GtfFile
 from .GtfParsedFile import GtfParsedFile
+from .GWASBigBed import GWASBigBed
+from .HiCBigBed import HiCBigBed
+from .TileDB import TileDB
 from .HDF5File import HDF5File
 from .Helper import get_range_helper
 from .utils import create_parser_object
\ No newline at end of file
