@@ -17,6 +17,9 @@ def create_parser_object(format, source, columns=None):
     from .BamFile import BamFile
     from .TbxFile import TbxFile
     from .GtfFile import GtfFile
+    from .GWASBigBed import GWASBigBed
+    from .HiCBigBed import HiCBigBed
+    from .TileDB import TileDB
 
     req_manager = {
         "BigWig": BigWig,
@@ -32,6 +35,9 @@ def create_parser_object(format, source, columns=None):
         "tbx": TbxFile,
         "tabix": TbxFile,
         "gtf": GtfFile,
+        "gwas": GWASBigBed,
+        "tiledb": TileDB,
+        "hic": HiCBigBed
     }
     
     return req_manager[format](source, columns)
